==> istio-model-v1beta1-5.11.1-sources.jar: annotations/io/fabric8/istio/api/security/v1beta1/RequestAuthenticationSpecFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluentImpl;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
public class RequestAuthenticationSpecFluentImpl<A extends io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent<A>{
  public RequestAuthenticationSpecFluentImpl() {
  }
  public RequestAuthenticationSpecFluentImpl(io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpec instance) {
    this.withJwtRules(instance.getJwtRules()); 
    this.withSelector(instance.getSelector()); 
  }
  private java.util.List<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> jwtRules;
  private io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder selector;
  public A addToJwtRules(java.lang.Integer index,io.fabric8.istio.api.security.v1beta1.JWTRule item) {
    if (this.jwtRules == null) {this.jwtRules = new java.util.ArrayList<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder>();}
    io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);_visitables.get("jwtRules").add(index >= 0 ? index : _visitables.get("jwtRules").size(), builder);this.jwtRules.add(index >= 0 ? index : jwtRules.size(), builder); return (A)this;
  }
  public A setToJwtRules(java.lang.Integer index,io.fabric8.istio.api.security.v1beta1.JWTRule item) {
    if (this.jwtRules == null) {this.jwtRules = new java.util.ArrayList<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder>();}
    io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);
    if (index < 0 || index >= _visitables.get("jwtRules").size()) { _visitables.get("jwtRules").add(builder); } else { _visitables.get("jwtRules").set(index, builder);}
    if (index < 0 || index >= jwtRules.size()) { jwtRules.add(builder); } else { jwtRules.set(index, builder);}
     return (A)this;
  }
  public A addToJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... items) {
    if (this.jwtRules == null) {this.jwtRules = new java.util.ArrayList<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder>();}
    for (io.fabric8.istio.api.security.v1beta1.JWTRule item : items) {io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);_visitables.get("jwtRules").add(builder);this.jwtRules.add(builder);} return (A)this;
  }
  public A addAllToJwtRules(java.util.Collection<io.fabric8.istio.api.security.v1beta1.JWTRule> items) {
    if (this.jwtRules == null) {this.jwtRules = new java.util.ArrayList<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder>();}
    for (io.fabric8.istio.api.security.v1beta1.JWTRule item : items) {io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);_visitables.get("jwtRules").add(builder);this.jwtRules.add(builder);} return (A)this;
  }
  public A removeFromJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... items) {
    for (io.fabric8.istio.api.security.v1beta1.JWTRule item : items) {io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);_visitables.get("jwtRules").remove(builder);if (this.jwtRules != null) {this.jwtRules.remove(builder);}} return (A)this;
  }
  public A removeAllFromJwtRules(java.util.Collection<io.fabric8.istio.api.security.v1beta1.JWTRule> items) {
    for (io.fabric8.istio.api.security.v1beta1.JWTRule item : items) {io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);_visitables.get("jwtRules").remove(builder);if (this.jwtRules != null) {this.jwtRules.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromJwtRules(java.util.function.Predicate<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> predicate) {
    if (jwtRules == null) return (A) this;
    final Iterator<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> each = jwtRules.iterator();
    final List visitables = _visitables.get("jwtRules");
    while (each.hasNext()) {
      io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildJwtRules instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.istio.api.security.v1beta1.JWTRule> getJwtRules() {
    return build(jwtRules);
  }
  public java.util.List<io.fabric8.istio.api.security.v1beta1.JWTRule> buildJwtRules() {
    return build(jwtRules);
  }
  public io.fabric8.istio.api.security.v1beta1.JWTRule buildJwtRule(java.lang.Integer index) {
    return this.jwtRules.get(index).build();
  }
  public io.fabric8.istio.api.security.v1beta1.JWTRule buildFirstJwtRule() {
    return this.jwtRules.get(0).build();
  }
  public io.fabric8.istio.api.security.v1beta1.JWTRule buildLastJwtRule() {
    return this.jwtRules.get(jwtRules.size() - 1).build();
  }
  public io.fabric8.istio.api.security.v1beta1.JWTRule buildMatchingJwtRule(java.util.function.Predicate<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> predicate) {
    for (io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder item: jwtRules) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingJwtRule(java.util.function.Predicate<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> predicate) {
    for (io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder item: jwtRules) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withJwtRules(java.util.List<io.fabric8.istio.api.security.v1beta1.JWTRule> jwtRules) {
    if (this.jwtRules != null) { _visitables.get("jwtRules").removeAll(this.jwtRules);}
    if (jwtRules != null) {this.jwtRules = new java.util.ArrayList<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder>(); for (io.fabric8.istio.api.security.v1beta1.JWTRule item : jwtRules){this.addToJwtRules(item);}} else { this.jwtRules = null;} return (A) this;
  }
  public A withJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... jwtRules) {
    if (this.jwtRules != null) {this.jwtRules.clear();}
    if (jwtRules != null) {for (io.fabric8.istio.api.security.v1beta1.JWTRule item :jwtRules){ this.addToJwtRules(item);}} return (A) this;
  }
  public java.lang.Boolean hasJwtRules() {
    return jwtRules != null && !jwtRules.isEmpty();
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> addNewJwtRule() {
    return new io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluentImpl.JwtRulesNestedImpl();
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> addNewJwtRuleLike(io.fabric8.istio.api.security.v1beta1.JWTRule item) {
    return new io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluentImpl.JwtRulesNestedImpl(-1, item);
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> setNewJwtRuleLike(java.lang.Integer index,io.fabric8.istio.api.security.v1beta1.JWTRule item) {
    return new io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluentImpl.JwtRulesNestedImpl(index, item);
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> editJwtRule(java.lang.Integer index) {
    if (jwtRules.size() <= index) throw new RuntimeException("Can't edit jwtRules. Index exceeds size.");
    return setNewJwtRuleLike(index, buildJwtRule(index));
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> editFirstJwtRule() {
    if (jwtRules.size() == 0) throw new RuntimeException("Can't edit first jwtRules. The list is empty.");
    return setNewJwtRuleLike(0, buildJwtRule(0));
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> editLastJwtRule() {
    int index = jwtRules.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last jwtRules. The list is empty.");
    return setNewJwtRuleLike(index, buildJwtRule(index));
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> editMatchingJwtRule(java.util.function.Predicate<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> predicate) {
    int index = -1;
    for (int i=0;i<jwtRules.size();i++) { 
    if (predicate.test(jwtRules.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching jwtRules. No match found.");
    return setNewJwtRuleLike(index, buildJwtRule(index));
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.istio.api.type.v1beta1.WorkloadSelector getSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public io.fabric8.istio.api.type.v1beta1.WorkloadSelector buildSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public A withSelector(io.fabric8.istio.api.type.v1beta1.WorkloadSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
  }
  public java.lang.Boolean hasSelector() {
    return this.selector != null;
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<A> withNewTypeSelector() {
    return new io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluentImpl.TypeSelectorNestedImpl();
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<A> withNewSelectorLike(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
    return new io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluentImpl.TypeSelectorNestedImpl(item);
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<A> editTypeSelector() {
    return withNewSelectorLike(getSelector());
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder().build());
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelectorLike(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RequestAuthenticationSpecFluentImpl that = (RequestAuthenticationSpecFluentImpl) o;
    if (jwtRules != null ? !jwtRules.equals(that.jwtRules) :that.jwtRules != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(jwtRules,  selector,  super.hashCode());
  }
  public class JwtRulesNestedImpl<N> extends io.fabric8.istio.api.security.v1beta1.JWTRuleFluentImpl<io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<N>> implements io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    JwtRulesNestedImpl(java.lang.Integer index,io.fabric8.istio.api.security.v1beta1.JWTRule item) {
      this.index = index;
      this.builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(this, item);
    }
    JwtRulesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(this);
    }
    io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) RequestAuthenticationSpecFluentImpl.this.setToJwtRules(index,builder.build());
    }
    public N endJwtRule() {
      return and();
    }
    
  }
  public class TypeSelectorNestedImpl<N> extends io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluentImpl<io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<N>> implements io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TypeSelectorNestedImpl(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
      this.builder = new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(this, item);
    }
    TypeSelectorNestedImpl() {
      this.builder = new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(this);
    }
    io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder builder;
    public N and() {
      return (N) RequestAuthenticationSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endTypeSelector() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-5.12.1-sources.jar: annotations/io/fabric8/istio/api/security/v1beta1/RequestAuthenticationSpecFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluentImpl;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;

 /**
  * Generated
  */
public class RequestAuthenticationSpecFluentImpl<A extends io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent<A>{
  public RequestAuthenticationSpecFluentImpl() {
  }
  public RequestAuthenticationSpecFluentImpl(io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpec instance) {
    this.withJwtRules(instance.getJwtRules()); 
    this.withSelector(instance.getSelector()); 
  }
  private java.util.List<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> jwtRules;
  private io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder selector;
  public A addToJwtRules(java.lang.Integer index,io.fabric8.istio.api.security.v1beta1.JWTRule item) {
    if (this.jwtRules == null) {this.jwtRules = new java.util.ArrayList<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder>();}
    io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);_visitables.get("jwtRules").add(index >= 0 ? index : _visitables.get("jwtRules").size(), builder);this.jwtRules.add(index >= 0 ? index : jwtRules.size(), builder); return (A)this;
  }
  public A setToJwtRules(java.lang.Integer index,io.fabric8.istio.api.security.v1beta1.JWTRule item) {
    if (this.jwtRules == null) {this.jwtRules = new java.util.ArrayList<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder>();}
    io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);
    if (index < 0 || index >= _visitables.get("jwtRules").size()) { _visitables.get("jwtRules").add(builder); } else { _visitables.get("jwtRules").set(index, builder);}
    if (index < 0 || index >= jwtRules.size()) { jwtRules.add(builder); } else { jwtRules.set(index, builder);}
     return (A)this;
  }
  public A addToJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... items) {
    if (this.jwtRules == null) {this.jwtRules = new java.util.ArrayList<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder>();}
    for (io.fabric8.istio.api.security.v1beta1.JWTRule item : items) {io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);_visitables.get("jwtRules").add(builder);this.jwtRules.add(builder);} return (A)this;
  }
  public A addAllToJwtRules(java.util.Collection<io.fabric8.istio.api.security.v1beta1.JWTRule> items) {
    if (this.jwtRules == null) {this.jwtRules = new java.util.ArrayList<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder>();}
    for (io.fabric8.istio.api.security.v1beta1.JWTRule item : items) {io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);_visitables.get("jwtRules").add(builder);this.jwtRules.add(builder);} return (A)this;
  }
  public A removeFromJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... items) {
    for (io.fabric8.istio.api.security.v1beta1.JWTRule item : items) {io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);_visitables.get("jwtRules").remove(builder);if (this.jwtRules != null) {this.jwtRules.remove(builder);}} return (A)this;
  }
  public A removeAllFromJwtRules(java.util.Collection<io.fabric8.istio.api.security.v1beta1.JWTRule> items) {
    for (io.fabric8.istio.api.security.v1beta1.JWTRule item : items) {io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(item);_visitables.get("jwtRules").remove(builder);if (this.jwtRules != null) {this.jwtRules.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromJwtRules(java.util.function.Predicate<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> predicate) {
    if (jwtRules == null) return (A) this;
    final Iterator<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> each = jwtRules.iterator();
    final List visitables = _visitables.get("jwtRules");
    while (each.hasNext()) {
      io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildJwtRules instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.istio.api.security.v1beta1.JWTRule> getJwtRules() {
    return build(jwtRules);
  }
  public java.util.List<io.fabric8.istio.api.security.v1beta1.JWTRule> buildJwtRules() {
    return build(jwtRules);
  }
  public io.fabric8.istio.api.security.v1beta1.JWTRule buildJwtRule(java.lang.Integer index) {
    return this.jwtRules.get(index).build();
  }
  public io.fabric8.istio.api.security.v1beta1.JWTRule buildFirstJwtRule() {
    return this.jwtRules.get(0).build();
  }
  public io.fabric8.istio.api.security.v1beta1.JWTRule buildLastJwtRule() {
    return this.jwtRules.get(jwtRules.size() - 1).build();
  }
  public io.fabric8.istio.api.security.v1beta1.JWTRule buildMatchingJwtRule(java.util.function.Predicate<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> predicate) {
    for (io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder item: jwtRules) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingJwtRule(java.util.function.Predicate<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> predicate) {
    for (io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder item: jwtRules) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withJwtRules(java.util.List<io.fabric8.istio.api.security.v1beta1.JWTRule> jwtRules) {
    if (this.jwtRules != null) { _visitables.get("jwtRules").removeAll(this.jwtRules);}
    if (jwtRules != null) {this.jwtRules = new java.util.ArrayList(); for (io.fabric8.istio.api.security.v1beta1.JWTRule item : jwtRules){this.addToJwtRules(item);}} else { this.jwtRules = null;} return (A) this;
  }
  public A withJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... jwtRules) {
    if (this.jwtRules != null) {this.jwtRules.clear();}
    if (jwtRules != null) {for (io.fabric8.istio.api.security.v1beta1.JWTRule item :jwtRules){ this.addToJwtRules(item);}} return (A) this;
  }
  public java.lang.Boolean hasJwtRules() {
    return jwtRules != null && !jwtRules.isEmpty();
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> addNewJwtRule() {
    return new io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluentImpl.JwtRulesNestedImpl();
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> addNewJwtRuleLike(io.fabric8.istio.api.security.v1beta1.JWTRule item) {
    return new io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluentImpl.JwtRulesNestedImpl(-1, item);
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> setNewJwtRuleLike(java.lang.Integer index,io.fabric8.istio.api.security.v1beta1.JWTRule item) {
    return new io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluentImpl.JwtRulesNestedImpl(index, item);
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> editJwtRule(java.lang.Integer index) {
    if (jwtRules.size() <= index) throw new RuntimeException("Can't edit jwtRules. Index exceeds size.");
    return setNewJwtRuleLike(index, buildJwtRule(index));
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> editFirstJwtRule() {
    if (jwtRules.size() == 0) throw new RuntimeException("Can't edit first jwtRules. The list is empty.");
    return setNewJwtRuleLike(0, buildJwtRule(0));
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> editLastJwtRule() {
    int index = jwtRules.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last jwtRules. The list is empty.");
    return setNewJwtRuleLike(index, buildJwtRule(index));
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<A> editMatchingJwtRule(java.util.function.Predicate<io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder> predicate) {
    int index = -1;
    for (int i=0;i<jwtRules.size();i++) { 
    if (predicate.test(jwtRules.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching jwtRules. No match found.");
    return setNewJwtRuleLike(index, buildJwtRule(index));
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.istio.api.type.v1beta1.WorkloadSelector getSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public io.fabric8.istio.api.type.v1beta1.WorkloadSelector buildSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public A withSelector(io.fabric8.istio.api.type.v1beta1.WorkloadSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
  }
  public java.lang.Boolean hasSelector() {
    return this.selector != null;
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<A> withNewTypeSelector() {
    return new io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluentImpl.TypeSelectorNestedImpl();
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<A> withNewSelectorLike(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
    return new io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluentImpl.TypeSelectorNestedImpl(item);
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<A> editTypeSelector() {
    return withNewSelectorLike(getSelector());
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder().build());
  }
  public io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelectorLike(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RequestAuthenticationSpecFluentImpl that = (RequestAuthenticationSpecFluentImpl) o;
    if (jwtRules != null ? !jwtRules.equals(that.jwtRules) :that.jwtRules != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(jwtRules,  selector,  super.hashCode());
  }
  public class JwtRulesNestedImpl<N> extends io.fabric8.istio.api.security.v1beta1.JWTRuleFluentImpl<io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<N>> implements io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.JwtRulesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    JwtRulesNestedImpl(java.lang.Integer index,io.fabric8.istio.api.security.v1beta1.JWTRule item) {
      this.index = index;
      this.builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(this, item);
    }
    JwtRulesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder(this);
    }
    io.fabric8.istio.api.security.v1beta1.JWTRuleBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) RequestAuthenticationSpecFluentImpl.this.setToJwtRules(index,builder.build());
    }
    public N endJwtRule() {
      return and();
    }
    
  }
  public class TypeSelectorNestedImpl<N> extends io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluentImpl<io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<N>> implements io.fabric8.istio.api.security.v1beta1.RequestAuthenticationSpecFluent.TypeSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TypeSelectorNestedImpl(io.fabric8.istio.api.type.v1beta1.WorkloadSelector item) {
      this.builder = new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(this, item);
    }
    TypeSelectorNestedImpl() {
      this.builder = new io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder(this);
    }
    io.fabric8.istio.api.type.v1beta1.WorkloadSelectorBuilder builder;
    public N and() {
      return (N) RequestAuthenticationSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endTypeSelector() {
      return and();
    }
    
  }
  
}
